@@ -4,48 +4,42 @@ OC.L10N.register(
     "Details" : "Detalles",
     "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
-    "Loading contacts …" : "Cargando contactos ...",
-    "Delete circle" : "Borrar círculo",
-    "General settings" : "Configuraciones generales",
-    "Send email" : "Enviar correo electrónico",
-    "Circles" : "Círculos",
-    "Create a new circle" : "Crear un nuevo círculo",
-    "Download" : "Descargar",
     "Rename" : "Renombrar",
+    "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
     "Copy link" : "Copiar liga",
+    "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
+    "Cancel" : "Cancelar",
+    "Add" : "Agregar",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
-    "Password protection" : "Protección con contraseña",
     "Save" : "Guardar",
-    "Description" : "Descripción",
-    "Cancel" : "Cancelar",
+    "Close" : "Cerrar",
+    "Folder" : "Carpeta",
+    "Create" : "Crear",
     "Invalid image" : "Imagen inválida",
+    "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
     "Title" : "Título",
-    "Address book" : "Libreta de direcciones",
-    "New contact" : "Nuevo contacto",
-    "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
-    "Personal circle" : "Círculo personal",
     "Pending" : "Pendiente",
-    "Close" : "Cerrar",
+    "None" : "Ninguno",
+    "Member" : "Miembro",
+    "New contact" : "Nuevo contacto",
     "Import" : "Importar",
     "Not grouped" : "No agrupado",
-    "Circle" : "Círculo",
     "User" : "Usuario",
     "Group" : "Grupo",
     "Email" : "Correo electrónico",
     "Contact" : "Contacto",
-    "Member" : "Miembro",
     "Moderator" : "Moderador",
     "Admin" : "Admin",
     "Owner" : "Dueño",
-    "Users" : "Usuarios",
+    "Privacy" : "Privacidad",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
     "Prefix" : "Prefijo",
@@ -78,7 +72,6 @@ OC.L10N.register(
     "Voice" : "Voz",
     "Car" : "Auto",
     "Work pager" : "Localizador de trabajo",
-    "Manager" : "Gerente",
     "Social network" : "Red social",
     "Spouse" : "Cónyuge",
     "Child" : "Hijo",
@@ -97,7 +90,9 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "None" : "Ninguno",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Loading contacts …" : "Cargando contactos ...",
+    "General settings" : "Configuraciones generales",
+    "Search contacts …" : "Buscar contactos ..."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
