@@ -1,8 +1,11 @@
 OC.L10N.register(
     "contacts",
     {
+    "Import contacts" : "导入联系人",
     "Details" : "详情",
     "All contacts" : "全部联系人",
+    "_Imported %n contact_::_Imported %n contacts_" : ["已导入 %n 位联系人"],
+    "_(skipped %n contact)_::_(skipped %n contacts)_" : ["（已跳过 %n 个联系人）"],
     "Contacts" : "联系人",
     "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud通讯录应用程序是Nextcloud的CardDAV服务器用户界面。您可以轻松使用您的Nextcloud同步各设备上的联系人，并在线上编辑。\n\n* 🚀 **与其他Nextcloud应用程序整合！** 目前有邮件和日历，还会有更多。\n* 🎉 **不会忘记生日！** 您可以将生日与其他重复的活动与您的Nextcloud日历同步。\n* 👥 **分享通讯录！** 您想与您的朋友或同事分享您的联系人吗？没问题！\n* 🙈 **我们不是在重复造轮子！** 基于出色且开源的SabreDAV库。",
@@ -12,20 +15,22 @@ OC.L10N.register(
     "There was an error fetching the member list" : "获取成员列表时发生一个错误",
     "Please select a team" : "请选择团队",
     "Loading team…" : "正在加载团队…",
-    "Loading contacts …" : "正在加载联系人 ...",
+    "Loading contacts …" : "正在加载联系人 …",
     "There are no contacts yet" : "尚无联系人",
     "Create contact" : "创建联系人",
     "There are no contacts in this group" : "此群组中没有联系人",
     "Create contacts" : "新建联系人",
     "Add contacts" : "添加联系人",
-    "Loading …" : "正在加载…",
+    "Loading …" : "正在加载 …",
     "Manage team" : "管理团队",
     "Leave team" : "离开团队",
     "Delete team" : "删除团队",
+    "Setting saved" : "设置已保存",
+    "Failed to save setting" : "无法保存设置",
     "Contacts settings" : "联系人设置",
-    "General settings" : "一般设置",
+    "General" : "常规",
     "Update avatars from social media" : "从社交媒体更新头像",
-    "(refreshed once per week)" : "（每周刷新）",
+    "Refreshed once per week" : "每周刷新一次",
     "Address books" : "地址簿",
     "Rename" : "重命名",
     "Export" : "导出",
@@ -41,6 +46,7 @@ OC.L10N.register(
     "An error occurred while creating the group" : "创建群组时出错",
     "This team already exists" : "此团队已存在",
     "An error happened during the creation of the team" : "创建团队时出错",
+    "Recently contacted" : "最近联系",
     "Contact groups" : "联系人群组",
     "Create a new contact group" : "创建联系人群组",
     "Contact group name" : "联系人群组名称",
@@ -52,13 +58,13 @@ OC.L10N.register(
     "Cannot copy" : "无法复制",
     "Copy link" : "复制链接",
     "Toggling of address book was not successful" : "通讯录切换不成功",
-    "This will delete the address book and every contacts within it" : "这将删除通讯录和其中的每个联系人",
-    "Delete {addressbook}?" : "删除 {addressbook} ？",
+    "This will delete the address book and every contacts within it" : "这将删除通讯录及其中的所有联系人",
+    "Delete {addressbook}?" : "删除 {addressbook}？",
     "This will unshare the address book and every contacts within it" : "这将取消共享通讯录及其中的每位联系人",
     "Unshare {addressbook}?" : "取消共享 {addressbook}？ ",
     "Deletion of address book was not successful." : "通讯录删除不成功",
     "Renaming of address book was not successful." : "通讯录重命名不成功",
-    "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
+    "{addressbookname} (Hidden)" : "{addressbookname}（隐藏）",
     "Download" : "下载",
     "Show" : "显示",
     "Unshare from me" : "我取消的共享",
@@ -71,13 +77,14 @@ OC.L10N.register(
     "Unable to change permissions" : "无法更改权限",
     "can edit" : "可编辑",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
-    "Import contacts" : "导入联系人",
     "Import into the {addressbookName} address book" : "导入 {addressbookName} 通讯录",
     "Select local file" : "选择本地文件",
     "Import from files" : "从文件导入",
-    "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
+    "Importing is disabled because there are no address books available" : "导入已禁用，因为没有可用的通讯录",
     "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
+    "New address book" : "新通讯录",
     "Add new address book" : "添加新通讯录",
+    "Cancel" : "取消",
     "Add" : "添加",
     "First name" : "名",
     "Last name" : "姓",
@@ -85,24 +92,46 @@ OC.L10N.register(
     "Phonetic last name" : "语音姓氏",
     "Display name" : "显示名称",
     "Last modified" : "上一次更改",
-    "Sort by {sorting}" : "以 {sorting} 排序",
+    "Sort contacts by" : "排序联系人方式",
     "Manages" : "管理",
     "Oversees" : "监督",
+    "An error happened during the config change" : "更改配置时发生一个错误",
     "Enforce password protection on files shared to this team" : "对与此团队共享的文件强制实施密码保护",
     "Use a unique password for all shares to this team" : "为此团队的全部共享使用唯一密码",
-    "Unique password …" : "独立密码 ...",
+    "Unique password …" : "唯一密码 …",
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
-    "An error happened during the config change" : "更改配置时发生一个错误",
+    "Close" : "关闭",
     "There is no description for this team" : "此团队没有描述",
     "Enter a description for the team" : "输入团队的描述",
-    "An error happened during description sync" : "描述同步期间发生一个错误",
-    "An error happened during name sync" : "名称同步期间发生了一个错误",
+    "Folder" : "文件夹",
+    "New folder" : "新文件夹",
+    "Folder name" : "文件夹名称",
+    "This will create a regular folder shared with the team. To create a Team Folder, please contact your {productName} administrator" : "这将创建一个与团队共享的常规文件夹。要创建团队文件夹，请联系您的 {productName} 管理员",
+    "Talk conversation" : "Talk 对话",
+    "New Talk conversation" : "新 Talk 对话",
+    "Conversation name" : "对话名称",
+    "Collective" : "集体",
+    "Calendar" : "日历",
+    "New calendar" : "新日历",
+    "Calendar name" : "日历名称",
+    "Deck board" : "Deck 面板",
+    "New Deck board" : "新 Deck 面板",
+    "Board name" : "面板名称",
+    "Deck app is not installed. Please install it to create team boards." : "未安装 Deck 应用。请安装它以创建团队面板。",
+    "Unknown resource type" : "未知资源类型",
+    "Team calendar \"{resourceName}\" created and shared with team" : "团队日历“{resourceName}”已创建并与团队共享",
+    "{resourceType} \"{resourceName}\" created and shared with team" : "{resourceType}“{resourceName}”已创建并与团队共享",
+    "A calendar named \"{name}\" already exists. Please choose a different name." : "名为“{name}”的日历已存在。请选择其他名称。",
+    "Failed to create {resourceType}: {error}" : "无法创建 {resourceType}：{error}",
+    "An error happened while saving {fields}" : "保存 {fields} 时出错",
     "Team name" : "团队名称",
+    "Team owner" : "团队所有者",
     "Edit" : "编辑",
-    "Cancel" : "取消",
     "Request to join" : "请求加入",
+    "Create" : "创建",
+    "Show in Calendar" : "在日历中显示",
     "Your request to join this team is pending approval" : "您加入此团队的请求正在等待批准",
     "You are not a member of {circle}" : "您并非 {circle} 的成员",
     "Members" : "成员",
@@ -153,17 +182,43 @@ OC.L10N.register(
     "Calendar events with you" : "与您分享的日历事件",
     "Deck cards with you" : "与您分享的卡片",
     "No shared items with this contact" : "与该联系人无共享项目",
+    "This contact cannot be moved" : "此联系人无法移动",
+    "This contact cannot be grouped" : "此联系人无法分组",
+    "Add contacts to groups" : "添加联系人到群组",
+    "Move contacts to addressbook" : "移动联系人到通讯录",
+    "Select groups" : "选择群组",
+    "Select addressbook" : "选择通讯录",
+    "Selected contacts" : "已选择联系人",
+    "Please note that only {count} of the {total} contacts can be added to a group" : "请注意，{total} 位联系人中只有 {count} 位可以添加到群组中",
+    "Please note that only {count} of the {total} contacts can be moved" : "请注意，{total} 位联系人中只有 {count} 位可以移动。",
+    "Move" : "移动",
+    "from {addressbook}" : "从 {addressbook}",
+    "Confirm merging contacts" : "确认合并联系人",
+    "The selected contacts have conflicting information. Choose which information to keep" : "所选联系人的信息存在冲突。请选择要保留的信息",
+    "Contacts can be merged" : "联系人可以合并",
+    "Groups" : "群组",
+    "Select groups to add the merged contact to" : "选择要添加合并联系人的群组",
+    "Merge contacts" : "合并联系人",
     "_Delete {number} contact_::_Delete {number} contacts_" : ["删除 {number} 位联系人"],
     "Please select at least one editable contact to delete" : "请至少选择一个可编辑的联系人进行删除",
+    "Please select two editable contacts to merge" : "请选择两个可编辑的联系人进行合并",
+    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["添加 {number} 位联系人到群组"],
+    "Please select at least one editable contact to add to a group" : "请至少选择一位可编辑的联系人以添加到群组中",
+    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["移动 {number} 位联系人到通讯录"],
+    "Please select at least one editable contact to move to an addressbook" : "请至少选择一位可编辑的联系人以移动到通讯录中",
     "Are you sure you want to proceed?" : "是否确定要继续？",
-    "Search contacts …" : "搜索联系人 ...",
+    "Add contacts to group" : "添加联系人到群组",
+    "Search contacts …" : "搜索联系人 …",
     "Unselect {number}" : "取消选择 {number}",
     "Add to {group}" : "添加到 {group}",
+    "Add members to {group}" : "添加成员到 {group}",
     "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "添加到群组",
+    "Add members to group" : "添加成员到群组",
     "Search {types}" : "搜索 {types}",
-    "Search for people to add" : "搜索要添加的人",
+    "Add guest" : "添加访客",
+    "Search for people to add" : "搜索要添加的联系人",
     "No results" : "无结果",
     "Add {type}" : "添加  {type}",
     "New team name" : "新团队名称",
@@ -172,14 +227,6 @@ OC.L10N.register(
     "Local team" : "本地团队",
     "This team will not be shared with the other instances of the global scale" : "此团队不会与全局范围内的其他实例共享",
     "Create team" : "创建团队",
-    "Unable to get the results" : "无法获得结果",
-    "Some members could not be added" : "无法添加一些成员",
-    "There was an issue adding members to the team" : "向团队添加成员时出现问题",
-    "Loading members list …" : "正在加载成员列表 ...",
-    "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
-    "You currently have no access to the member list" : "您目前无法访问成员列表",
-    "Add to {circle}" : "添加到 {circle}",
-    "Pending" : "待定",
     "Promote as sole owner" : "提升为唯一所有人",
     "Promote to {level}" : "提升为 {level}",
     "Demote to {level}" : "降级为 {level}",
@@ -191,16 +238,30 @@ OC.L10N.register(
     "Accept membership request" : "接受成员身份请求",
     "Reject membership request" : "拒绝成员身份请求",
     "Manage level" : "管理级别",
-    "Remove member" : "删除成员",
-    "Select chart …" : "选择图表 ...",
+    "Remove member" : "移除成员",
+    "Unable to get the results" : "无法获得结果",
+    "Some members could not be added" : "无法添加一些成员",
+    "There was an issue adding members to the team" : "向团队添加成员时出现问题",
+    "Loading members list …" : "正在加载成员列表 …",
+    "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
+    "You currently have no access to the member list" : "您目前无法访问成员列表",
+    "Add to {team}" : "添加到 {team}",
+    "Invite members to {team}" : "邀请成员加入 {team}",
+    "Pending" : "待定",
+    "Select chart …" : "选择图表 …",
     "Chart" : "图表",
     "Select Date" : "选择日期",
     "Select type" : "选择类型",
     "Add contact in group" : "添加联系人到群组",
     "None" : "无",
     "Select option" : "选择选项",
+    "note" : "备注",
+    "email" : "电子邮件",
+    "send an email" : "发送邮件",
     "Personal dates" : "个人行程",
     "Add property of this type" : "为此类型添加属性",
+    "Member" : "成员",
+    "This is a read-only group managed by administrators. Group members can only view this group." : "这是由管理员管理的只读组。组成员只能查看此组。",
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
     "Group {group} not found" : "未找到群组 {group} ",
@@ -209,7 +270,6 @@ OC.L10N.register(
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 位联系人已添加到 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在将 {success} 位联系人添加到 {name}"],
     "_{count} error_::_{count} errors_" : ["{count} 个错误"],
-    "Close" : "关闭",
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在将 %n 位联系人导入 {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 位联系人导入 {addressbook}"],
     "No data for this contact" : "此联系人无数据",
@@ -228,7 +288,6 @@ OC.L10N.register(
     "Link copied to the clipboard" : "链接已复制到剪贴板",
     "Could not copy link to the clipboard." : "无法复制链接到剪贴板",
     "Not grouped" : "未分组",
-    "Recently contacted" : "最近联系",
     "Organization chart" : "组织图",
     "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "团队是一群人，你可以自己创建，也可以与他们共享数据。它们可以由 Nextcloud 实例的其它账号或账号组组成，也可以由通讯录中的联系人组成，甚至可以由外部人员组成，只需输入他们的电子邮箱地址即可。",
     "Team" : "团队",
@@ -236,7 +295,6 @@ OC.L10N.register(
     "Group" : "群组",
     "Email" : "电子邮件",
     "Contact" : "联系人",
-    "Member" : "成员",
     "Moderator" : "主持人",
     "Admin" : "管理员",
     "Owner" : "所有者",
@@ -245,12 +303,13 @@ OC.L10N.register(
     "Members need to accept invitation" : "成员需要接受邀请",
     "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成员资格必须由主持人确认/接受（要求“任何人都可以申请成员资格”）",
     "Members can also invite" : "成员也可以邀请",
+    "Membership" : "成员资格",
     "Prevent teams from being a member of another team" : "防止团队成为其他团队的成员",
+    "Privacy" : "隐私",
     "Visible to everyone" : "对所有人可见",
     "users" : "用户",
     "Users" : "用户",
     "groups" : "群组",
-    "Groups" : "群组",
     "teams" : "团队",
     "email addresses" : "电子邮件地址",
     "Email addresses" : "电子邮件地址",
@@ -260,7 +319,7 @@ OC.L10N.register(
     "Prefix" : "前缀",
     "Suffix" : "后缀",
     "Nickname" : "昵称",
-    "Notes" : "说明",
+    "Notes" : "备注",
     "Website" : "网站",
     "Location" : "地点",
     "Federated Cloud ID" : "联合云 ID",
@@ -315,22 +374,22 @@ OC.L10N.register(
     "Unknown" : "未知",
     "Time zone" : "时区",
     "Spoken languages" : "口语",
-    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
+    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 位联系人无法读取"],
     "An error has occurred in team(s). Check the console for more details." : "团队中出现错误。有关更多详情，请查看控制台。",
-    "Unable to create team {circleName}" : "无法创建团队 {圈子名称}",
+    "Unable to create team {circleName}" : "无法创建团队 {circleName}",
     "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
     "Unable to delete contact" : "无法删除联系人",
-    "Password protection" : "密码保护",
-    "Team owned by {owner}" : "{owner} 拥有的团队",
-    "Team settings" : "团队设置",
-    "Description" : "描述",
-    "Team resources" : "团队资源",
-    "Anything shared with this team will show up here" : "与此团队共享的任何内容都将显示在此处",
-    "Settings" : "设置",
-    "Actions" : "操作",
-    "Team members" : "团队成员",
-    "Add members" : "添加成员",
-    "Visibility" : "可见性",
-    "Team membership" : "团队成员"
+    "Loading contacts …" : "正在加载联系人…",
+    "Loading …" : "正在加载…",
+    "General settings" : "一般设置",
+    "(refreshed once per week)" : "（每周刷新）",
+    "{addressbookname} (Disabled)" : "{addressbookname}（已禁用）",
+    "Unique password …" : "唯一密码…",
+    "Search contacts …" : "搜索联系人…",
+    "Invite members to team" : "邀请成员加入团队",
+    "Loading members list …" : "正在加载成员列表…",
+    "Add to {circle}" : "添加到 {circle}",
+    "Select chart …" : "选择图表…",
+    "_Imported %n contact (skipped %d)_::_Imported %n contacts (skipped %d)_" : ["已导入 %n 位联系人（跳过 %d 位）"]
 },
 "nplurals=1; plural=0;");
